OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Ní féidir scríobh san eolaire \"config\"!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Is féidir é seo a shocrú de ghnáth trí rochtain scríofa a thabhairt don fhreastalaí gréasáin ar an eolaire cumraíochta.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ach, más fearr leat an comhad config.php a choinneáil léite amháin, socraigh an rogha \"config_is_read_only\" le bheith fíor ann.",
    "See %s" : "Féach %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Níl feidhmchlár %1$s i láthair nó tá leagan nach bhfuil comhoiriúnach leis an bhfreastalaí seo. Seiceáil eolaire na n-aipeanna le do thoil.",
    "Sample configuration detected" : "Braitheadh ​​cumraíocht shamplach",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Braitheadh ​​go bhfuil an chumraíocht samplach cóipeáilte. Is féidir leis seo do shuiteáil a bhriseadh agus ní thacaítear leis. Léigh na doiciméid sula ndéanfaidh tú athruithe ar config.php le do thoil",
    "The page could not be found on the server." : "Níorbh fhéidir an leathanach a fháil ar an bhfreastalaí.",
    "%s email verification" : "%s fíorú ríomhphoist",
    "Email verification" : "Fíorú ríomhphoist",
    "Click the following button to confirm your email." : "Cliceáil ar an gcnaipe seo a leanas chun do ríomhphost a dhearbhú.",
    "Click the following link to confirm your email." : "Cliceáil ar an nasc seo a leanas chun do ríomhphost a dhearbhú.",
    "Confirm your email" : "Deimhnigh do ríomhphost",
    "Other activities" : "Gníomhaíochtaí eile",
    "%1$s and %2$s" : "%1$s agus %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s agus %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s agus %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s agus %5$s",
    "Education bundle" : "Beart oideachais",
    "Enterprise bundle" : "Pacáiste fiontraíochta",
    "Groupware bundle" : "Pacáiste earraí grúpa",
    "Hub bundle" : "Mol bundle",
    "Public sector bundle" : "Beart earnála poiblí",
    "Social sharing bundle" : "Pacáiste comhroinnte sóisialta",
    "PHP %s or higher is required." : "Tá PHP %s nó níos airde ag teastáil.",
    "PHP with a version lower than %s is required." : "Tá PHP le leagan níos ísle ná %s ag teastáil.",
    "%sbit or higher PHP required." : "Tá %sbit nó PHP níos airde ag teastáil.",
    "The following architectures are supported: %s" : "Tacaítear leis na hailtireachtaí seo a leanas: %s",
    "The following databases are supported: %s" : "Tacaítear leis na bunachair shonraí seo a leanas: %s",
    "The command line tool %s could not be found" : "Níorbh fhéidir uirlis na n-orduithe %s a aimsiú",
    "The library %s is not available." : "Níl an leabharlann %s ar fáil.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Leabharlann %1$s le leagan níos airde ná %2$s ag teastáil - leagan %3$s ar fáil.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Leabharlann %1$s le leagan níos ísle ná %2$s ag teastáil - leagan %3$s ar fáil.",
    "The following platforms are supported: %s" : "Tacaítear leis na hardáin seo a leanas: %s",
    "Server version %s or higher is required." : "Tá leagan freastalaí %s nó níos airde ag teastáil.",
    "Server version %s or lower is required." : "Tá leagan freastalaí %s nó níos ísle ag teastáil.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Ní mór gur riarthóir, fo-riarthóir é cuntas logáilte isteach nó go bhfuil ceart speisialta faighte aige chun an socrú seo a rochtain",
    "Your current IP address doesn't allow you to perform admin actions" : "Ní cheadaíonn do sheoladh IP reatha duit gníomhartha riaracháin a dhéanamh",
    "Logged in account must be an admin or sub admin" : "Ní mór gur riarthóir nó fo-riarthóir é cuntas logáilte isteach",
    "Logged in account must be an admin" : "Ní mór gur riarthóir é cuntas logáilte isteach",
    "Wiping of device %s has started" : "Tá tús curtha le glanadh an ghléis %s",
    "Wiping of device »%s« has started" : "Tá tús curtha le glanadh an ghléis »%s«",
    "»%s« started remote wipe" : "Chuir »%s« tús le cianbhaint",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Chuir gléas nó feidhmchlár »%s« tús leis an bpróiseas cianda cuimilte. Gheobhaidh tú ríomhphost eile nuair a bheidh an próiseas críochnaithe",
    "Wiping of device %s has finished" : "Tá glanadh an ghléis %s críochnaithe",
    "Wiping of device »%s« has finished" : "Tá glanadh an ghléis »%s« críochnaithe",
    "»%s« finished remote wipe" : "Chríochnaigh »%s« an cianda wipe",
    "Device or application »%s« has finished the remote wipe process." : "Chuir gléas nó feidhmchlár »%s« críoch leis an bpróiseas cianda cuimilte.",
    "Remote wipe started" : "Thosaigh wipe cianda",
    "A remote wipe was started on device %s" : "Cuireadh tús le cuimilteán cianda ar ghléas %s",
    "Remote wipe finished" : "Cianda wipe críochnaithe",
    "The remote wipe on %s has finished" : "Tá an cianchuimilt ar %s críochnaithe",
    "Authentication" : "Fíordheimhniú",
    "Unknown filetype" : "Cineál comhaid anaithnid",
    "Invalid image" : "Íomhá neamhbhailí",
    "Avatar image is not square" : "Níl an íomhá avatar cearnach",
    "Files" : "Comhaid",
    "View profile" : "Féach ar phróifíl",
    "same time" : "am céanna",
    "_%nh_::_%nh_" : ["%nuair","%nuair","%nuair","%nuair","%nuair"],
    "_%nm_::_%nm_" : ["%nm","%nm","%nm","%nm","%nm"],
    "%s ahead" : "%s romhainn",
    "%s behind" : "%s taobh thiar",
    "Local time: %s" : "Am áitiúil: %s",
    "today" : "inniu",
    "tomorrow" : "amárach",
    "yesterday" : "inné",
    "_in %n day_::_in %n days_" : ["i %n lá","i %n lá","i %n lá","i %n lá","i %n lá"],
    "_%n day ago_::_%n days ago_" : ["%n lá ó shin","%n lá ó shin","%n lá ó shin","%n lá ó shin","%n lá ó shin"],
    "next month" : "an mhí seo chugainn",
    "last month" : "an mhí seo caite",
    "_in %n month_::_in %n months_" : ["i %n mí","i %n mí","i %n mí","i %n mí","i %n mí"],
    "_%n month ago_::_%n months ago_" : ["%n mí ó shin","%n mí ó shin","%n mí ó shin","%n mí ó shin","%n mí ó shin"],
    "next year" : "an bhliain seo chugainn",
    "last year" : "anuraidh",
    "_in %n year_::_in %n years_" : ["i %n bhliain","i %n bliain","i %n bliain","i %n bliain","i %n bliain"],
    "_%n year ago_::_%n years ago_" : ["%n bliain ó shin","%n bliain ó shin","%n bliain ó shin","%n bliain ó shin","%n bliain ó shin"],
    "_in %n hour_::_in %n hours_" : ["i %n uair","i %n uair","i %n uair","i %n uair","i %n uair"],
    "_%n hour ago_::_%n hours ago_" : ["%n uair ó shin","%n uair ó shin","%n uair ó shin","%n uair ó shin","%n uair ó shin"],
    "_in %n minute_::_in %n minutes_" : ["i %n nóiméad","i %n nóiméad","i %n nóiméad","i %n nóiméad","i %n nóiméad"],
    "_%n minute ago_::_%n minutes ago_" : ["%n nóiméad ó shin","%n nóiméad ó shin","%n nóiméad ó shin","%n nóiméad ó shin","%n nóiméad ó shin"],
    "in a few seconds" : "i gceann cúpla soicind",
    "seconds ago" : "soicind ó shin",
    "Empty file" : "Comhad folamh",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modúl le haitheantas: níl %s ann. Cumasaigh é i socruithe d'aipeanna nó déan teagmháil le do riarthóir le do thoil.",
    "No file conversion providers available" : "Níl soláthraithe comhshó comhad ar fáil",
    "File is too large to convert" : "Tá an comhad rómhór le tiontú",
    "Destination does not match conversion extension" : "Ní hionann an ceann scríbe agus an síneadh tiontaithe",
    "Could not convert file" : "Níorbh fhéidir an comhad a thiontú",
    "Destination does not exist" : "Níl ceann scríbe ann",
    "Destination is not creatable" : "Níl ceann scríbe cruthaithe",
    "Dot files are not allowed" : "Ní cheadaítear comhaid ponc",
    "%1$s (renamed)" : "%1$s (athainmnithe)",
    "renamed file" : "comhad athainmnithe",
    "\"%1$s\" is a forbidden file or folder name." : "Is ainm toirmiscthe comhaid nó fillteáin é \"%1$s\".",
    "\"%1$s\" is a forbidden prefix for file or folder names." : "Réimír toirmiscthe é \"%1$s\" d'ainmneacha comhaid nó fillteán.",
    "\"%1$s\" is not allowed inside a file or folder name." : "Ní cheadaítear \"%1$s\" taobh istigh d'ainm comhaid nó fillteáin.",
    "\"%1$s\" is a forbidden file type." : "Is cineál comhaid toirmiscthe é \"%1$s\".",
    "Filenames must not end with \"%1$s\"." : "Ní cheadaítear \"%1$s\" a bheith mar chríoch ar chomhainmneacha.",
    "Invalid parent path" : "Conair tuismitheora neamhbhailí",
    "File already exists" : "Tá an comhad ann cheana féin",
    "Invalid path" : "Conair neamhbhailí",
    "Failed to create file from template" : "Theip ar chruthú comhad ón teimpléad",
    "Templates" : "Teimpléid",
    "Storage %s cannot be moved" : "Ní féidir stóráil %s a bhogadh",
    "Moving a share (%s) into a shared folder is not allowed" : "Ní cheadaítear sciar (%s) a bhogadh isteach i bhfillteán comhroinnte",
    "Moving a storage (%s) into a shared folder is not allowed" : "Ní cheadaítear stóras (%s) a bhogadh isteach i bhfillteán comhroinnte",
    "Moving a share (%s) into another share (%s) is not allowed" : "Ní cheadaítear sciar (%s) a aistriú go sciar eile (%s).",
    "Moving a share (%s) into another storage (%s) is not allowed" : "Ní cheadaítear sciar (%s) a aistriú go stóras eile (%s).",
    "Moving a storage (%s) into a share (%s) is not allowed" : "Ní cheadaítear stóras (%s) a aistriú go sciar (%s).",
    "Moving a storage (%s) into another storage (%s) is not allowed" : "Ní cheadaítear stóras (%s) a aistriú go stóras eile (%s).",
    "Path contains invalid segments" : "Tá míreanna neamhbhailí sa chonair",
    "Filename is a reserved word" : "Focal forchoimeádta is ea ainm comhaid",
    "Filename contains at least one invalid character" : "Tá carachtar neamhbhailí amháin ar a laghad san ainm comhaid",
    "Filename is too long" : "Tá an t-ainm comhaid ró-fhada",
    "Empty filename is not allowed" : "Ní cheadaítear ainm comhaid folamh",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Ní féidir aip \"%s\" a shuiteáil toisc nach féidir an comhad appinfo a léamh.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Ní féidir aip \"%s\" a shuiteáil toisc nach bhfuil sé comhoiriúnach leis an leagan seo den fhreastalaí.",
    "__language_name__" : "__language_name__",
    "This is an automatically sent email, please do not reply." : "Seo ríomhphost a sheoltar go huathoibríoch, ná freagair le do thoil.",
    "Help & privacy" : "Cabhair & príobháideacht",
    "Appearance and accessibility" : "Cuma agus inrochtaineacht",
    "Apps" : "Feidhmchláir",
    "Personal settings" : "Socruithe pearsanta",
    "Administration settings" : "Socruithe riaracháin",
    "Settings" : "Socruithe",
    "Log out" : "Logáil Amach",
    "Accounts" : "Cuntais",
    "Email" : "Ríomhphost",
    "Mail %s" : "Ríomhphost %s",
    "Fediverse" : "Feidearálach",
    "View %s on the fediverse" : "Amharc ar %s ar an bhfuinneog",
    "Phone" : "Fón",
    "Call %s" : "Glaoigh ar %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Féach ar %s ar Twitter",
    "Website" : "Suíomh Gréasáin",
    "Visit %s" : "Tabhair cuairt ar %s",
    "Address" : "Seoladh",
    "Profile picture" : "Pictiúr próifíle",
    "About" : "Faoi",
    "Display name" : "Ainm taispeána",
    "Headline" : "Ceannlíne",
    "Organisation" : "Eagraíocht",
    "Role" : "Ról",
    "Pronouns" : "Forainmneacha",
    "Unknown account" : "Cuntas anaithnid",
    "Additional settings" : "Socruithe breise",
    "Enter the database Login and name for %s" : "Iontráil logáil isteach sa bhunachar sonraí agus ainm do %s",
    "Enter the database Login for %s" : "Iontráil logáil isteach an bhunachar sonraí le haghaidh %s",
    "Enter the database name for %s" : "Iontráil ainm an bhunachair shonraí le haghaidh %s",
    "You cannot use dots in the database name %s" : "Ní féidir poncanna a úsáid in ainm an bhunachair shonraí %s",
    "MySQL Login and/or password not valid" : "Níl logáil isteach MySQL agus/nó pasfhocal bailí",
    "You need to enter details of an existing account." : "Ní mór duit sonraí cuntas reatha a chur isteach.",
    "Oracle connection could not be established" : "Níorbh fhéidir nasc Oracle a bhunú",
    "Oracle Login and/or password not valid" : "Níl logáil isteach Oracle agus/nó pasfhocal bailí",
    "PostgreSQL Login and/or password not valid" : "Níl logáil isteach agus/nó pasfhocal PostgreSQL bailí",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Ní thacaítear le Mac OS X agus ní oibreoidh %s i gceart ar an ardán seo. Bain úsáid as ar do phriacal féin!",
    "For the best results, please consider using a GNU/Linux server instead." : "Chun na torthaí is fearr a fháil, smaoinigh le do thoil ar fhreastalaí GNU/Linux a úsáid ina ionad.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Is cosúil go bhfuil an cás %s seo ag rith ar thimpeallacht PHP 32-giotán agus tá an open_basedir cumraithe i php.ini. Beidh fadhbanna le comhaid os cionn 4 GB mar thoradh air seo agus tá sé an-díspreagadh.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Bain an socrú open_basedir laistigh de do php.ini nó aistrigh go PHP 64-giotán le do thoil.",
    "Set an admin Login." : "Socraigh logáil isteach admin.",
    "Set an admin password." : "Socraigh pasfhocal riarthóra.",
    "Cannot create or write into the data directory %s" : "Ní féidir an eolaire sonraí %s a chruthú ná a scríobh",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Má tá inneall %s á roinnt ní mór an comhéadan OCP\\Share_Backend a chur i bhfeidhm",
    "Sharing backend %s not found" : "Ní bhfuarthas inneall comhroinnte %s",
    "Sharing backend for %s not found" : "Ní bhfuarthas inneall roinnte le haghaidh %s",
    "%1$s shared %2$s with you" : "%1$s roinnte %2$s leat",
    "Open %s" : "Oscailte %s",
    "%1$s via %2$s" : "%1$s trí %2$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$sroinnte%2$sleat agus ba mhaith leat a chur leis:",
    "%1$s shared %2$s with you and wants to add" : "%1$s roinnte%2$sleat agus ba mhaith leat cur leis",
    "%s added a note to a file shared with you" : " chuir %s nóta le comhad a roinntear leat",
    "Passwords are enforced for link and mail shares" : "Cuirtear pasfhocail i bhfeidhm le haghaidh naisc agus scaireanna ríomhphoist",
    "Share recipient is not a valid user" : "Ní úsáideoir bailí é faighteoir scaireanna",
    "Share recipient is not a valid group" : "Ní grúpa bailí é faighteoir scaireanna",
    "Share recipient should be empty" : "Ba chóir go mbeadh faighteoir scaireanna folamh",
    "Share recipient should not be empty" : "Níor cheart go mbeadh faighteoir scaireanna folamh",
    "Share recipient is not a valid circle" : "Ní ciorcal bailí é an faighteoir comhroinnte",
    "Unknown share type" : "Cineál scaire anaithnid",
    "Share initiator must be set" : "Ní mór thionscnóir scaireanna a shocrú",
    "Cannot share with yourself" : "Ní féidir a roinnt leat féin",
    "Shared path must be set" : "Ní mór cosán roinnte a shocrú",
    "Shared path must be either a file or a folder" : "Ní mór go mbeadh an cosán roinnte ina chomhad nó ina fhillteán",
    "You cannot share your root folder" : "Ní féidir leat do fhréamhfhillteán a roinnt",
    "You are not allowed to share %s" : "Níl cead agat %s a roinnt",
    "Valid permissions are required for sharing" : "Teastaíonn ceadanna bailí chun comhroinnt",
    "File shares cannot have create or delete permissions" : "Ní féidir ceadanna cruthaithe nó scriosta a bheith ag scaireanna comhaid",
    "Cannot increase permissions of %s" : "Ní féidir ceadanna %s a mhéadú",
    "Shares need at least read permissions" : "Teastaíonn ceadanna léite ar a laghad ó scaireanna",
    "Files cannot be shared with delete permissions" : "Ní féidir comhaid a roinnt le ceadanna scriosta",
    "Files cannot be shared with create permissions" : "Ní féidir comhaid a roinnt le ceadanna cruthaithe",
    "Expiration date is in the past" : "Tá an dáta éaga san am atá caite",
    "Expiration date is enforced" : "Cuirtear an dáta éaga i bhfeidhm",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Cannot set expiration date more than %n day in the future","Ní féidir dáta éaga níos mó ná %n lá a shocrú amach anseo","Ní féidir dáta éaga níos mó ná %n lá a shocrú amach anseo","Ní féidir dáta éaga níos mó ná %n lá a shocrú amach anseo","Ní féidir dáta éaga níos mó ná %n lá a shocrú amach anseo"],
    "Sharing is only allowed with group members" : "Ní cheadaítear comhroinnt ach le baill an ghrúpa",
    "Sharing %s failed, because this item is already shared with the account %s" : "Theip ar chomhroinnt %s, toisc go bhfuil an mhír seo roinnte cheana féin leis an gcuntas %s",
    "Group sharing is now allowed" : "Ceadaítear comhroinnt grúpa anois",
    "Sharing is only allowed within your own groups" : "Ní cheadaítear comhroinnt ach amháin laistigh de do ghrúpaí féin",
    "Path is already shared with this group" : "Tá an chonair roinnte leis an ngrúpa seo cheana féin",
    "Link sharing is not allowed" : "Ní cheadaítear nasc a roinnt",
    "Public upload is not allowed" : "Ní cheadaítear uaslódáil phoiblí",
    "You cannot share a folder that contains other shares" : "Ní féidir leat fillteán a roinnt ina bhfuil scaireanna eile",
    "Sharing is disabled" : "Tá roinnt díchumasaithe",
    "Sharing is disabled for you" : "Tá comhroinnt díchumasaithe duit",
    "Cannot share with the share owner" : "Ní féidir a roinnt leis an úinéir na scaireanna",
    "Share does not have a full ID" : "Níl aitheantas iomlán ag scair",
    "Cannot change share type" : "Ní féidir cineál na scaire a athrú",
    "Can only update recipient on user shares" : "Ní féidir ach faighteoir a nuashonrú ar scaireanna úsáideora",
    "Cannot enable sending the password by Talk with an empty password" : "Ní féidir an pasfhocal a sheoladh trí Talk a chumasú le pasfhocal folamh",
    "Cannot enable sending the password by Talk without setting a new password" : "Ní féidir an pasfhocal a sheoladh le Talk a chumasú gan pasfhocal nua a shocrú",
    "Cannot disable sending the password by Talk without setting a new password" : "Ní féidir seoladh an fhocail faire le Talk a dhíchumasú gan focal faire nua a shocrú",
    "Share provider does not support accepting" : "Ní thacaíonn soláthraí scaireanna le glacadh",
    "Cannot change target of link share" : "Ní féidir an sprioc maidir le comhroinnt naisc a athrú",
    "Invalid share recipient" : "Faighteoir scaireanna neamhbhailí",
    "Group \"%s\" does not exist" : "Níl grúpa \"%s\" ann",
    "The requested share does not exist anymore" : "Níl an sciar iarrtha ann a thuilleadh",
    "The requested share comes from a disabled user" : "Tagann an sciar iarrtha ó úsáideoir díchumasaithe",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Níor cruthaíodh an t-úsáideoir toisc go bhfuil an teorainn úsáideora bainte amach. Seiceáil d'fhógraí chun tuilleadh a fhoghlaim.",
    "Could not find category \"%s\"" : "Níorbh fhéidir an chatagóir \"%s\" a aimsiú",
    "Input text" : "Téacs ionchuir",
    "The input text" : "An téacs ionchuir",
    "Sunday" : "Domhnach",
    "Monday" : "Dé Luain",
    "Tuesday" : "Dé Máirt",
    "Wednesday" : "Dé Céadaoin",
    "Thursday" : "Déardaoin",
    "Friday" : "Aoine",
    "Saturday" : "Sathairn",
    "Sun." : "Dom.",
    "Mon." : "Lua.",
    "Tue." : "Mái.",
    "Wed." : "Céa.",
    "Thu." : "Déa.",
    "Fri." : "Aoi.",
    "Sat." : "Sat.",
    "Su" : "Do",
    "Mo" : "Lu",
    "Tu" : "Má",
    "We" : "Cé",
    "Th" : "Dé",
    "Fr" : "Ao",
    "Sa" : "Sa",
    "January" : "Eanáir",
    "February" : "Feabhra",
    "March" : "Márta",
    "April" : "Aibreán",
    "May" : "Bealtaine",
    "June" : "Meitheamh",
    "July" : "Iúil",
    "August" : "Lúnasa",
    "September" : "Meán Fómhair",
    "October" : "Deireadh Fómhair",
    "November" : "Samhain",
    "December" : "Nollaig",
    "Jan." : "Ean.",
    "Feb." : "Fea.",
    "Mar." : "Már.",
    "Apr." : "Aib.",
    "May." : "Bea.",
    "Jun." : "Mei.",
    "Jul." : "Iúi.",
    "Aug." : "Lún.",
    "Sep." : "MFo.",
    "Oct." : "DFo.",
    "Nov." : "Sam.",
    "Dec." : "Nol.",
    "A valid password must be provided" : "Ní mór pasfhocal bailí a sholáthar",
    "The Login is already being used" : "Tá an Logáil Isteach á úsáid cheana féin",
    "Could not create account" : "Níorbh fhéidir cuntas a chruthú",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Ní cheadaítear ach na carachtair seo a leanas i logáil isteach: \"a-z\", \"A-Z\", \"0-9\", spásanna agus \"_.@-'\"",
    "A valid Login must be provided" : "Ní mór Logáil Isteach bailí a sholáthar",
    "Login contains whitespace at the beginning or at the end" : "Tá spás bán sa logáil isteach ag an tús nó ag an deireadh",
    "Login must not consist of dots only" : "Níor cheart go gcuimseodh logáil isteach poncanna amháin",
    "Login is too long" : "Tá logáil isteach ró-fhada",
    "Login is invalid because files already exist for this user" : "Tá logáil isteach neamhbhailí toisc go bhfuil comhaid ann cheana don úsáideoir seo",
    "Account disabled" : "Díchumasaíodh an cuntas",
    "Login canceled by app" : "Cealaíodh logáil isteach ag an aip",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Ní féidir aip \"%1$s\" a shuiteáil toisc nach bhfuil na spleáchais seo a leanas comhlíonta: %2$s",
    "a safe home for all your data" : "baile sábháilte do do shonraí go léir",
    "Application is not enabled" : "Níl feidhmchlár cumasaithe",
    "Authentication error" : "Earráid fhíordheimhnithe",
    "Token expired. Please reload page." : "Token imithe in éag. Athlódáil an leathanach le do thoil.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Níl aon tiománaithe bunachar sonraí (sqlite, mysql, nó postgresql) suiteáilte.",
    "Cannot write into \"config\" directory." : "Ní féidir scríobh san eolaire \"config\".",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Is féidir é seo a shocrú de ghnáth trí rochtain scríofa a thabhairt don fhreastalaí gréasáin ar an eolaire cumraíochta. Féach %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Nó, más fearr leat an comhad config.php a choinneáil léite amháin, socraigh an rogha \"config_is_read_only\" le bheith fíor ann. Féach %s",
    "Cannot write into \"apps\" directory." : "Ní féidir scríobh isteach sa bhfillteán \"apps\".",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Is féidir é seo a shocrú de ghnáth trí rochtain scríofa a thabhairt don fhreastalaí gréasáin ar an eolaire apps nó an Siopa Aip a dhíchumasú sa chomhad cumraíochta.",
    "Cannot create \"data\" directory." : "Ní féidir eolaire \"sonraí\" a chruthú.",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Is féidir é seo a shocrú de ghnáth trí rochtain scríofa a thabhairt don fhreastalaí gréasáin ar an bhfréamheolaire. Féach %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Is féidir ceadanna a shocrú de ghnáth trí rochtain scríofa a thabhairt don fhreastalaí gréasáin ar an bhfréamheolaire. Féach %s.",
    "Your data directory is not writable." : "Níl do chomhadlann sonraí inscríofa.",
    "Setting locale to %s failed." : "Theip ar shocrú logánta go %s.",
    "Please install one of these locales on your system and restart your web server." : "Suiteáil ceann de na logaí seo ar do chóras agus atosaigh do fhreastalaí gréasáin le do thoil.",
    "PHP module %s not installed." : "Modúl PHP %s gan suiteáil.",
    "Please ask your server administrator to install the module." : "Iarr ar riarthóir do fhreastalaí an modúl a shuiteáil le do thoil. ",
    "PHP setting \"%s\" is not set to \"%s\"." : "Níl an socrú PHP \"%s\" socraithe go \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Má choigeartaítear an socrú seo i php.ini, reáchtálfar Nextcloud arís",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "Tá<code>mbstring.func_overload</code> socraithe go <code>%s</code> in ionad an luacha ionchais<code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Chun an tsaincheist seo a réiteach socraigh <code>mbstring.func_overload</code> go <code>0</code> i do php.ini.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Is cosúil go bhfuil PHP socraithe chun bloic doc inlíne a stialladh. Beidh sé seo a dhéanamh ar roinnt aipeanna lárnacha dorochtana.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Is dócha gur taisce/luasaire ar nós Zend OPcache nó eAccelerator ba chúis leis seo.",
    "PHP modules have been installed, but they are still listed as missing?" : "Tá modúil PHP suiteáilte, ach tá siad liostaithe fós mar in easnamh?",
    "Please ask your server administrator to restart the web server." : "Iarr ar riarthóir do fhreastalaí an freastalaí gréasáin a atosú le do thoil.",
    "The required %s config variable is not configured in the config.php file." : "Níl an athróg cumraíochta riachtanach %s cumraithe sa chomhad config.php.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Iarr ar riarthóir do fhreastalaí cumraíocht Nextcloud a sheiceáil le do thoil.",
    "Your data directory is readable by other people." : "Tá d'eolaire sonraí inléite ag daoine eile.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Athraigh na ceadanna go 0770 ionas nach féidir le daoine eile an t-eolaire a liostú le do thoil.",
    "Your data directory must be an absolute path." : "Ní mór gur cosán iomlán é d'eolaire sonraí.",
    "Check the value of \"datadirectory\" in your configuration." : "Seiceáil an luach \"datadirectory\" i do chumraíocht.",
    "Your data directory is invalid." : "Tá d'eolaire sonraí neamhbhailí.",
    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Cinntigh go bhfuil comhad dar teideal \"%1$s\" i bhfréamh an eolaire sonraí. Ba cheart go mbeadh an t-ábhar ann: \"%2$s\"",
    "Action \"%s\" not supported or implemented." : "Ní thacaítear le gníomh \"%s\" nó ní chuirtear i bhfeidhm é.",
    "Authentication failed, wrong token or provider ID given" : "Theip ar fhíordheimhniú, comhartha mícheart nó aitheantas soláthraí tugtha",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Paraiméadair in easnamh chun an t-iarratas a chomhlánú. Paraiméadair ar Iarraidh: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "Aitheantas \"%1$s\" in úsáid cheana ag soláthraí cónaidhm néil \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Cloud Federation Provider le ID: níl \"%s\" ann.",
    "Could not obtain lock type %d on \"%s\"." : "Níorbh fhéidir cineál glas %d a fháil ar \"%s\".",
    "Storage unauthorized. %s" : "Stóráil neamhúdaraithe. %s",
    "Storage incomplete configuration. %s" : "Cumraíocht stórála neamhiomlán. %s",
    "Storage connection error. %s" : "Earráid nasc stórála. %s",
    "Storage is temporarily not available" : "Níl stóráil ar fáil go sealadach",
    "Storage connection timeout. %s" : "Teorainn ama ceangail stórála. %s",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Le gur féidir an tseiceáil seo a rith caithfidh tú a chinntiú gur féidir le do fhreastalaí Gréasáin nascadh leis féin. Mar sin caithfidh sé a bheith in ann réiteach agus ceangal a dhéanamh le ceann amháin ar a laghad dá chuid `fearainn_iontaofa` nó an `overwrite.cli.url`. D'fhéadfadh an teip seo a bheith mar thoradh ar mhímheaitseáil DNS ar thaobh an fhreastalaí nó riail balla dóiteáin amach.",
    "Transcribe audio" : "Trascríobh fuaime",
    "Transcribe the things said in an audio" : "Tras-scríobh na rudaí a dúradh i bhfuaim",
    "Audio input" : "Ionchur fuaime",
    "The audio to transcribe" : "Fuaime le tras-scríobh",
    "Transcription" : "Trascríobh",
    "The transcribed text" : "An téacs tras-scríofa",
    "Chat with an agent" : "Déan comhrá le gníomhaire",
    "Chat message" : "Teachtaireacht comhrá",
    "A chat message to send to the agent." : "Teachtaireacht comhrá le seoladh chuig an ngníomhaire.",
    "Confirmation" : "Daingniú",
    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Cibé ar cheart gníomhartha a iarradh roimhe seo a dhearbhú: 0 le séanadh agus 1 le deimhniú.",
    "Conversation token" : "Comhartha comhartha",
    "A token representing the conversation." : "Comhartha a léiríonn an comhrá.",
    "Generated response" : "Freagra ginte",
    "The response from the chat model." : "An freagra ón múnla comhrá.",
    "The new conversation token" : "An comhartha comhrá nua",
    "Send this along with the next interaction." : "Seol é seo in éineacht leis an gcéad idirghníomhaíocht eile.",
    "Requested actions by the agent" : "Gníomhartha iarrtha ag an ngníomhaire",
    "Actions that the agent would like to carry out in JSON format." : "Gníomhartha ar mhaith leis an ngníomhaire iad a dhéanamh i bhformáid JSON.",
    "Context write" : "Comhthéacs scríobh",
    "Writes text in a given style based on the provided source material." : "Scríobhann sé téacs i stíl ar leith bunaithe ar an mbunábhar a cuireadh ar fáil.",
    "Writing style" : "Stíl scríbhneoireachta",
    "Demonstrate a writing style that you would like to immitate" : "Taispeáin stíl scríbhneoireachta ar mhaith leat aithris a dhéanamh uirthi",
    "Source material" : "Bunábhar",
    "The content that would like to be rewritten in the new writing style" : "An t-ábhar ar mhaith leis a bheith athscríofa sa stíl scríbhneoireachta nua",
    "Generated text" : "Téacs ginte",
    "The generated text with content from the source material in the given style" : "An téacs ginte le hábhar ón mbunábhar sa stíl tugtha",
    "Emoji generator" : "Gineadóir Emoji",
    "Takes text and generates a representative emoji for it." : "Glacann sé téacs agus gineann sé emoji ionadaíoch dó.",
    "The text to generate an emoji for" : "An téacs le haghaidh emoji a ghiniúint",
    "Generated emoji" : "Emoji ginte",
    "The generated emoji based on the input text" : "An emoji ginte bunaithe ar an téacs ionchuir",
    "Generate image" : "Gin íomhá",
    "Generate an image from a text prompt" : "Gin íomhá ó leid téacs",
    "Prompt" : "Leid",
    "Describe the image you want to generate" : "Déan cur síos ar an íomhá is mian leat a ghiniúint",
    "Number of images" : "Líon na n-íomhánna",
    "How many images to generate" : "Cé mhéad íomhánna atá le giniúint",
    "Output images" : "Íomhánna aschuir",
    "The generated images" : "Na híomhánna a ghintear",
    "Generate speech" : "Gin urlabhra",
    "Generate speech from a transcript" : "Gin urlabhra ó thrascríbhinn",
    "Write transcript that you want the assistant to generate speech from" : "Scríobh an tras-scríbhinn ar mhaith leat go nginfeadh an cúntóir urlabhra uaidh",
    "Output speech" : "Aschur cainte",
    "The generated speech" : "An chaint ghinte",
    "Free text to text prompt" : "Teimpléad téacs go téacs saor in aisce,",
    "Runs an arbitrary prompt through a language model that returns a reply" : "Ritheann leid treallach trí mhúnla teanga a sheolann freagra ar ais",
    "Describe a task that you want the assistant to do or ask a question" : "Déan cur síos ar thasc a theastaíonn uait don chúntóir a dhéanamh nó ceist a chur",
    "Generated reply" : "Gineadh freagra",
    "The generated text from the assistant" : "An téacs a ghintear ón gcúntóir",
    "Change Tone" : "Athraigh Ton",
    "Change the tone of a piece of text." : "Athraigh ton píosa téacs.",
    "Write a text that you want the assistant to rewrite in another tone." : "Scríobh téacs a theastaíonn uait don chúntóir a athscríobh i dton eile.",
    "Desired tone" : "Ton inmhianaithe",
    "In which tone should your text be rewritten?" : "Cén ton inar cheart do théacs a athscríobh?",
    "The rewritten text in the desired tone, written by the assistant:" : "An téacs athscríofa sa ton inmhianaithe, scríofa ag an gcúntóir:",
    "Chat" : "Comhrá",
    "Chat with the assistant" : "Comhrá leis an cúntóir",
    "System prompt" : "Leid córais",
    "Define rules and assumptions that the assistant should follow during the conversation." : "Sainmhínigh na rialacha agus na toimhdí ba chóir don chúntóir a leanúint le linn an chomhrá.",
    "Chat history" : "Stair comhrá",
    "The history of chat messages before the current message, starting with a message by the user" : "Stair na dteachtaireachtaí comhrá roimh an teachtaireacht reatha, ag tosú le teachtaireacht ón úsáideoir",
    "Response message" : "Teachtaireacht freagartha",
    "The generated response as part of the conversation" : "An freagra ginte mar chuid den chomhrá",
    "Chat with tools" : "Comhrá le huirlisí",
    "Chat with the language model with tool calling support." : "Déan comhrá leis an múnla teanga le tacaíocht glaonna uirlis.",
    "Tool message" : "Teachtaireacht uirlise",
    "The result of tool calls in the last interaction" : "Mar thoradh ar ghlaonna uirlis san idirghníomhaíocht dheireanach",
    "Available tools" : "Uirlisí atá ar fáil",
    "The available tools in JSON format" : "Na huirlisí atá ar fáil i bhformáid JSON",
    "The response from the chat model" : "An freagra ón múnla comhrá",
    "Tool calls" : "Glaonna uirlisí",
    "Tools call instructions from the model in JSON format" : "Glaonn uirlisí treoracha ón tsamhail i bhformáid JSON",
    "Formalize text" : "Téacs a fhoirmiú",
    "Takes a text and makes it sound more formal" : "Glacann sé téacs agus déanann sé fuaim níos foirmiúla",
    "Write a text that you want the assistant to formalize" : "Scríobh téacs ar mhaith leat an cúntóir a chur ar bhonn foirmiúil",
    "Formalized text" : "Téacs foirmiúil",
    "The formalized text" : "An téacs foirmiúil",
    "Generate a headline" : "Gin ceannlíne",
    "Generates a possible headline for a text." : "Gineann sé ceannlíne féideartha le haghaidh téacs.",
    "Original text" : "Téacs bunaidh",
    "The original text to generate a headline for" : "An téacs bunaidh chun ceannlíne a ghiniúint le haghaidh",
    "The generated headline" : "An ceannlíne ginte",
    "Proofread" : "Promhléamh",
    "Proofreads a text and lists corrections" : "Léann profaí téacs agus liostaíonn sé ceartúcháin",
    "Text" : "Téacs",
    "The text to proofread" : "An téacs le léamh profaí",
    "Corrections" : "Ceartúcháin",
    "The corrections that should be made in your text" : "Na ceartúcháin ba chóir a dhéanamh i do théacs",
    "Reformulate text" : "Téacs a athchóiriú",
    "Takes a text and reformulates it" : "Glacann sé téacs agus athfhoirmíonn sé é",
    "Write a text that you want the assistant to reformulate" : "Scríobh téacs a theastaíonn uait go ndéanfadh an cúntóir athfhoirmliú",
    "Reformulated text" : "Téacs athchóirithe",
    "The reformulated text, written by the assistant" : "An téacs athfhoirmithe, scríofa ag an cúntóir",
    "Simplify text" : "Téacs a shimpliú",
    "Takes a text and simplifies it" : "Glacann sé téacs agus simplíonn sé é",
    "Write a text that you want the assistant to simplify" : "Scríobh téacs ar mhaith leat an cúntóir a shimpliú",
    "Simplified text" : "Téacs simplithe",
    "The simplified text" : "An téacs simplithe",
    "Summarize" : "Achoimre",
    "Summarizes a text" : "Déanann sé achoimre ar théacs",
    "The original text to summarize" : "An téacs bunaidh chun achoimre a dhéanamh",
    "Summary" : "Achoimre",
    "The generated summary" : "An achoimre ginte",
    "Extract topics" : "Ábhair sliocht",
    "Extracts topics from a text and outputs them separated by commas" : "Sliocht topaicí as téacs agus aschuir iad scartha le camóga",
    "The original text to extract topics from" : "An buntéacs chun topaicí a bhaint astu",
    "Topics" : "Ábhair",
    "The list of extracted topics" : "An liosta de na hábhair a bhaintear",
    "Translate" : "Aistrigh",
    "Translate text from one language to another" : "Aistrigh téacs ó theanga amháin go teanga eile",
    "Origin text" : "Téacs tionscnaimh",
    "The text to translate" : "An téacs a aistriú",
    "Origin language" : "Teanga tionscnaimh",
    "The language of the origin text" : "Teanga an bhuntéacs",
    "Target language" : "Sprioctheanga",
    "The desired language to translate the origin text in" : "An teanga atá ag teastáil chun an buntéacs a aistriú in",
    "Result" : "Toradh",
    "The translated text" : "An téacs aistrithe",
    "Free prompt" : "Saor in aisce leideanna",
    "Runs an arbitrary prompt through the language model." : "Ritheann leid treallach tríd an múnla teanga.",
    "Generate headline" : "Gin ceannlíne",
    "Summarizes text by reducing its length without losing key information." : "Déanann sé achoimre ar théacs trína fhad a laghdú gan eochairfhaisnéis a chailliúint.",
    "Extracts topics from a text and outputs them separated by commas." : "Sliocht topaicí as téacs agus aschuir iad scartha le camóga.",
    "Education Edition" : "Eagrán Oideachais",
    "File name is a reserved word" : "Focal in áirithe is ea ainm comhaid",
    "File name contains at least one invalid character" : "Tá carachtar neamhbhailí amháin ar a laghad san ainm comhaid",
    "File name is too long" : "Tá ainm an chomhaid rófhada",
    "Users" : "Úsáideoirí",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s shared »%2$s« with you and wants to add:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s shared »%2$s« with you and wants to add",
    "»%s« added a note to a file shared with you" : "»%s« added a note to a file shared with you",
    "Open »%s«" : "Oscail »%s«",
    "%1$s shared »%2$s« with you" : "Roinn %1$s »%2$s« leat",
    "%1$s shared »%2$s« with you." : "Roinn %1$s »%2$s« leat.",
    "Click the button below to open it." : "Cliceáil ar an gcnaipe thíos chun é a oscailt.",
    "File is currently busy, please try again later" : "Tá an comhad gnóthach faoi láthair, bain triail eile as ar ball le do thoil",
    "Cannot download file" : "Ní féidir an comhad a íoslódáil",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Cinntigh go bhfuil comhad darb ainm \".ocdata\" i bhfréamh an eolaire sonraí."
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
